@@ -1,5 +1,6 @@
 use crate::*;
-/// Creates a schema in the database by writing to the system Schema table.
+
+/// Create a schema in the database by writing to the system Schema table.
 pub fn create_schema(db: &DB, name: &str) {
     if let Some(_id) = get_schema(db, name) {
         panic!("Schema '{}' already exists", name);
@@ -10,6 +11,7 @@ pub fn create_schema(db: &DB, name: &str) {
     row.values[0] = Value::String(Rc::new(name.to_string()));
     t.insert(db, &mut row);
 }
+
 /// Create a new table in the database by writing to the system Table and Column tables.
 pub fn create_table(db: &DB, info: &ColInfo) {
     if let Some(_t) = get_table(db, &info.name) {
@@ -49,6 +51,7 @@ pub fn create_table(db: &DB, info: &ColInfo) {
         }
     }
 }
+
 /// Create a new table index by writing to the system Index and IndexColumn tables.
 pub fn create_index(db: &DB, info: &IndexInfo) {
     if let Some(table) = db.get_table(&info.tname) {
@@ -83,10 +86,11 @@ pub fn create_index(db: &DB, info: &IndexInfo) {
         panic!("table not found: {}", &info.tname.str());
     }
 }
-/// Creates or alters a function in the database by saving the source into the Function system table.
+
+/// Create or alter a function in the database by saving the source into the Function system table.
 pub fn create_function(db: &DB, name: &ObjRef, source: Rc<String>, alter: bool) {
     if let Some(schema_id) = get_schema(db, &name.schema) {
-        let t = db.get_table(&ObjRef::new("sys", "Function")).unwrap();
+        let t = &db.sys_function;
         if alter {
             // Columns are Schema(0), Name(1), Definition(2).
             let keys = vec![
@@ -126,24 +130,28 @@ pub fn create_function(db: &DB, name: &ObjRef, source: Rc<String>, alter: bool)
         panic!("schema [{}] not found", &name.schema);
     }
 }
-/// Gets the id of a schema from a name.
+
+/// Get the id of a schema from a name.
 pub fn get_schema(db: &DB, sname: &str) -> Option<i64> {
     if let Some(id) = db.schemas.borrow().get(sname) {
         return Some(*id);
     }
     let t = &db.sys_schema;
-    for (pp, off) in t.scan(db) {
+    let keys = vec![
+        Value::String(Rc::new(sname.to_string())),
+    ];
+    if let Some((pp, off)) = t.ix_get(db, keys, 0) {
         let p = &pp.borrow();
         let a = t.access(p, off);
-        if a.str(db, 0) == sname {
-            let id = a.id();
-            db.schemas.borrow_mut().insert(sname.to_string(), id);
-            return Some(a.id());
-        }
+        debug_assert!( a.str(db, 0) == sname );
+        let id = a.id();
+        db.schemas.borrow_mut().insert(sname.to_string(), id);
+        return Some(a.id());
     }
     None
 }
-/// Get id, root, id_gen for specified table.
+
+/// Get the id, root, id_gen for specified table.
 fn get_table0(db: &DB, name: &ObjRef) -> Option<(i64, i64, i64)> {
     if let Some(schema_id) = get_schema(db, &name.schema) {
         let t = &db.sys_table;
@@ -160,11 +168,12 @@ fn get_table0(db: &DB, name: &ObjRef) -> Option<(i64, i64, i64)> {
     }
     None
 }
+
 /// Gets a table from the database.
 pub fn get_table(db: &DB, name: &ObjRef) -> Option<TablePtr> {
     if let Some((table_id, root, id_gen)) = get_table0(db, name) {
         let mut info = ColInfo::empty(name.clone());
-        // Load columns. Columns are Table, Name, Type
+        // Get columns. Columns are Table, Name, Type
         let t = &db.sys_column;
         let key = Value::Int(table_id);
         for (pp, off) in t.scan_key(db, key, 0) {
@@ -176,7 +185,7 @@ pub fn get_table(db: &DB, name: &ObjRef) -> Option<TablePtr> {
             info.add(cname, ctype);
         }
         let table = Table::new(table_id, root as u64, id_gen, Rc::new(info));
-        // Load indexes. Columns are Root, Table, Name.
+        // Get indexes. Columns are Root, Table, Name.
         let t = &db.sys_index;
         let key = Value::Int(table_id);
         for (pp, off) in t.scan_key(db, key, 0) {
@@ -204,10 +213,11 @@ pub fn get_table(db: &DB, name: &ObjRef) -> Option<TablePtr> {
         None
     }
 }
-/// Gets then parses a function from the database.
+
+/// Get then parse a function from the database.
 pub fn get_function(db: &DB, name: &ObjRef) -> Option<FunctionPtr> {
     if let Some(schema_id) = get_schema(db, &name.schema) {
-        let t = db.get_table(&ObjRef::new("sys", "Function")).unwrap();
+        let t = &db.sys_function;
         let keys = vec![
             Value::Int(schema_id),
             Value::String(Rc::new(name.name.to_string())),
@@ -225,10 +235,11 @@ pub fn get_function(db: &DB, name: &ObjRef) -> Option<FunctionPtr> {
     }
     None
 }
+
 /// Get the id of a function.
 pub fn get_function_id(db: &DB, name: &ObjRef) -> Option<i64> {
     if let Some(schema_id) = get_schema(db, &name.schema) {
-        let t = db.get_table(&ObjRef::new("sys", "Function")).unwrap();
+        let t = &db.sys_function;
         let keys = vec![
             Value::Int(schema_id),
             Value::String(Rc::new(name.name.to_string())),
@@ -241,6 +252,7 @@ pub fn get_function_id(db: &DB, name: &ObjRef) -> Option<i64> {
     }
     None
 }
+
 /// Parse a function definition.
 fn parse_function(db: &DB, source: Rc<String>) -> FunctionPtr {
     let mut p = Parser::new(&source, db);
@@ -255,6 +267,7 @@ fn parse_function(db: &DB, source: Rc<String>) -> FunctionPtr {
         source,
     })
 }
+
 /// Update IdGen field for a table.
 pub fn save_id_gen(db: &DB, id: u64, val: i64) {
     let t = &db.sys_table;
@@ -264,6 +277,7 @@ pub fn save_id_gen(db: &DB, id: u64, val: i64) {
     wa.set_int(5, val);
     t.file.set_dirty(p, &pp);
 }
+
 /// Get the IdGen field for a table. This is only needed to initialise system tables.
 pub fn get_id_gen(db: &DB, id: u64) -> i64 {
     let t = &db.sys_table;
